NavItem class

Constructors

const

Properties

activeColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
inactiveColor Color?
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen Widget
final
showBadge bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited